
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.033.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28",
    "Test::CPAN::Meta" => 0,
    "Test::EOL" => 0,
    "Test::NoTabs" => 0
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Auto-create TimeMoment objects from date and datetime columns.",
  "dist_author" => [
    "Nigel Metheringham <nigelm\@cpan.org>"
  ],
  "dist_name" => "DBIx-Class-InflateColumn-TimeMoment",
  "dist_version" => "0.01",
  "license" => "perl",
  "module_name" => "DBIx::Class::InflateColumn::TimeMoment",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "DBIx::Class" => 0,
    "DBIx::Class::Carp" => 0,
    "Try::Tiny" => 0,
    "base" => 0,
    "namespace::clean" => 0,
    "perl" => "5.008",
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "Carp" => 0,
    "DBIx::Class::Core" => 0,
    "DBIx::Class::Schema" => 0,
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "SQL::Translator" => "0.11018",
    "Scalar::Util" => 0,
    "Test::More" => "0.94",
    "Time::Moment" => 0,
    "lib" => 0
  }
);


my %fallback_build_requires = (
  "Carp" => 0,
  "DBIx::Class::Core" => 0,
  "DBIx::Class::Schema" => 0,
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "SQL::Translator" => "0.11018",
  "Scalar::Util" => 0,
  "Test::CPAN::Meta" => 0,
  "Test::EOL" => 0,
  "Test::More" => "0.94",
  "Test::NoTabs" => 0,
  "Time::Moment" => 0,
  "lib" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
